@@ -519,7 +519,7 @@ def test_job_client_list(mocker):
     mocker.patch.object(JobClient, "_get", return_value=[JOB_SUMMARY])
     schema_mock = mocker.patch("faculty.clients.job._JobSummarySchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert client.list(PROJECT_ID) == [JOB_SUMMARY]
 
     schema_mock.assert_called_once_with(many=True)
@@ -533,7 +533,7 @@ def test_job_client_create(mocker):
     response_schema_mock = mocker.patch("faculty.clients.job._JobIdSchema")
     mocker.patch.object(_JobDefinitionSchema, "dump")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert (
         client.create(
             PROJECT_ID,
@@ -563,7 +563,7 @@ def test_job_client_get(mocker):
     mocker.patch.object(JobClient, "_get", return_value=JOB)
     schema_mock = mocker.patch("faculty.clients.job._JobSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert client.get(PROJECT_ID, JOB_ID) == JOB
 
     schema_mock.assert_called_once_with()
@@ -576,7 +576,7 @@ def test_job_client_get(mocker):
 def test_job_client_update_metadata(mocker):
     mocker.patch.object(JobClient, "_put_raw")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     client.update_metadata(PROJECT_ID, JOB_ID, "A name", "A desc")
 
     JobClient._put_raw.assert_called_once_with(
@@ -589,7 +589,7 @@ def test_job_client_update_definition(mocker):
     mocker.patch.object(JobClient, "_put_raw")
     mocker.patch.object(_JobDefinitionSchema, "dump")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     client.update_definition(PROJECT_ID, JOB_ID, JOB_DEFINITION)
 
     _JobDefinitionSchema.dump.assert_called_once_with(JOB_DEFINITION)
@@ -603,7 +603,7 @@ def test_job_client_create_run(mocker):
     mocker.patch.object(JobClient, "_post", return_value=RUN_ID)
     schema_mock = mocker.patch("faculty.clients.job._RunIdSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert (
         client.create_run(
             PROJECT_ID,
@@ -635,7 +635,7 @@ def test_job_client_create_run_default_parameter_value_sets(mocker):
     mocker.patch.object(JobClient, "_post", return_value=RUN_ID)
     schema_mock = mocker.patch("faculty.clients.job._RunIdSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert client.create_run(PROJECT_ID, JOB_ID) == RUN_ID
 
     schema_mock.assert_called_once_with()
@@ -650,7 +650,7 @@ def test_job_client_list_runs(mocker):
     mocker.patch.object(JobClient, "_get", return_value=LIST_RUNS_RESPONSE)
     schema_mock = mocker.patch("faculty.clients.job._ListRunsResponseSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert client.list_runs(PROJECT_ID, JOB_ID) == LIST_RUNS_RESPONSE
 
     schema_mock.assert_called_once_with()
@@ -665,7 +665,7 @@ def test_job_client_list_runs_page(mocker):
     mocker.patch.object(JobClient, "_get", return_value=LIST_RUNS_RESPONSE)
     schema_mock = mocker.patch("faculty.clients.job._ListRunsResponseSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert (
         client.list_runs(PROJECT_ID, JOB_ID, start=20, limit=10)
         == LIST_RUNS_RESPONSE
@@ -686,7 +686,7 @@ def test_job_client_get_run(mocker, run_identifier):
     mocker.patch.object(JobClient, "_get", return_value=RUN)
     schema_mock = mocker.patch("faculty.clients.job._RunSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert client.get_run(PROJECT_ID, JOB_ID, run_identifier) == RUN
 
     schema_mock.assert_called_once_with()
@@ -708,7 +708,7 @@ def test_job_client_get_subrun(mocker, run_identifier, subrun_identifier):
     mocker.patch.object(JobClient, "_get", return_value=SUBRUN)
     schema_mock = mocker.patch("faculty.clients.job._SubrunSchema")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     assert (
         client.get_subrun(
             PROJECT_ID, JOB_ID, run_identifier, subrun_identifier
@@ -731,7 +731,7 @@ def test_job_client_get_subrun(mocker, run_identifier, subrun_identifier):
 def test_job_client_cancel_run(mocker, run_identifier):
     mocker.patch.object(JobClient, "_delete_raw")
 
-    client = JobClient(mocker.Mock())
+    client = JobClient(mocker.Mock(), mocker.Mock())
     client.cancel_run(PROJECT_ID, JOB_ID, run_identifier)
 
     JobClient._delete_raw.assert_called_once_with(
